function [ distances_atrib ] = Feat_Extr( B )
% This function extract the features from the grayscale otolith image B. The output
% distances_atrib is a charactristics vecotr (1*32)obtained from the otolith
% contours to train and test the model

%% Convert the image to binary and prepare the ROI 

E=im2bw(B,0.1);
F=imclearborder(E);
G=imfill(F,'holes');
H=bwareaopen(G,50000);

%% Get coordinates of the contour points

structBoundaries = bwboundaries(H);
xy=structBoundaries{1}; 
x = xy(:, 2); 
y = xy(:, 1); 

%% determining the centroid of the image
measurements = regionprops(H, 'Centroid');
centroid = measurements.Centroid; % [row, column], NOT [x,y]

%% Calculating the angles corresponding to the distances (this stage is only for illustrating the representative signal (distance ad a function of angle))of the otolith image
deltaY = y - centroid(2);
deltaX = x - centroid(1);
angles = atan2(deltaY,deltaX);
angles = radtodeg(angles);

%% Calculating the distances between centroid and contour points

distances = sqrt((y - centroid(2)).^2 + (x - centroid(1)).^2);
% sorting
[angles, IX] = sort(angles);
distances = distances(IX);

distances = interpft(distances,1000);    % downsampling the calculated distances to 1000 samples            


%% calculating short-time Fourier transform (STFT, spectrogram) of the distances (charactristic 1D signal)

w = gausswin(100);               % gausswin can be replaced by other windowing functions (Table 6 of the manuscript)
[S,F,T] = spectrogram(distances,w,40);   
S_abs= abs(S);          % calculating absolute values from the spectrogram
S_phase= angle(S);      % calculating angles from the spectrogram

%% calculating charactristic vector obtained from the otolith image

Z_abs = zscore(S_abs);
Z_phase= zscore(S_phase);

distances_atrib= [max(Z_abs) max(Z_phase)];    


end

